@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Controller';
 use HTTP::AcceptLanguage;
 use Mojo::Path;
 use Mojo::File qw(path);
-use Mojo::Util qw ( decode encode url_unescape xml_escape);#encode 
+use Mojo::Util qw ( decode encode url_unescape xml_escape);# 
 use Time::Piece;# module replaces the standard localtime and gmtime functions with implementations that return objects
 use Mojo::Asset::File;
 
@@ -67,9 +67,13 @@ sub post {
     if $c->req->is_limit_exceeded;
 
   my $file = $c->req->upload('file')
-    or return return $c->render(json=>{error=>$c->i18n('Where your parameters?')});
-  my $name = url_unescape($c->param('name') || $file->filename);
-  my $to = $file_path->child(encode('UTF-8', $name));
+    or return $c->render(json=>{error=>$c->i18n('Where is your upload file?')});
+  my $name = (my $ename) = url_unescape($c->param('name') || $file->filename);
+  utf8::upgrade($ename);
+  return $c->render(json=>{error=>$c->i18n('Provide the name of upload file')})
+    unless $ename =~ /\S/i;
+  
+  my $to = $file_path->child($ename);
   
   return $c->render(json=>{error=>$c->i18n('path is not a directory')})
     unless -d $file_path;
@@ -173,7 +177,13 @@ sub dir {
 sub new_dir {
   my ($c, $path, $dir) = @_;
   
-  my $to = $path->child(encode('UTF-8', url_unescape($dir)));
+  my $edir = url_unescape($dir);
+  utf8::upgrade($edir);
+  
+  return $c->render(json=>{error=>$c->i18n('provide the name of new directory')})
+    unless $edir =~ /\S/i;
+  
+  my $to = $path->child($edir);#
   
   return $c->render(json=>{error=>$c->i18n('dir or file exists')})
     if -e $to;
@@ -187,7 +197,13 @@ sub new_dir {
 sub rename {
   my ($c, $path, $rename) = @_;
   
-  my $to = $path->sibling(encode('UTF-8', url_unescape($rename)));
+  my $ename = url_unescape($rename);
+  utf8::upgrade($ename);
+  
+  return $c->render(json=>{error=>$c->i18n('provide new name')})
+    unless $ename =~ /\S/i;
+  
+  my $to = $path->sibling($ename);
   
   return $c->render(json=>{error=>$c->i18n('dir or file exists')})
     if -e $to;
@@ -203,13 +219,17 @@ sub delete {
   my ($c, $path, $delete) = @_;
   my @delete = ();
   for (@$delete) {
-    my $d = $path->sibling(encode('UTF-8', url_unescape($_)));
+    my $del = url_unescape($_);
+    utf8::upgrade($del);
+    push @delete, $c->i18n('provide the name of deleted dir')
+      and next
+      unless $del =~ /\S/i;
+    my $d = $path->sibling($del);
     push @delete, $c->i18n('dir or file does not exists')
       and next
       unless -e $d;
     push @delete, eval {$d->remove_tree()} ? 1 : 0,
   }
-
   
   $c->render(json=>{ok=>\@delete});
 }
@@ -311,15 +331,16 @@ sub _dom_attrs {# for markdown
   my $content = $child1->content;
   if ($content =~ s|^(?:\s*\{([^\}]+)\}\s*)||) {
     my $attrs = $1;
-    while ($attrs =~ s|([\w\-]+\s*:\s*[^;]+;)|| ) {# styles
+    utf8::upgrade($attrs);
+    while ($attrs =~ s|([\S\-]+\s*:\s*[^;]+;)|| ) {# styles
       #~ warn "\tstyle=", $1;
       $parent->{style} .= " $1";
     }
-    while ($attrs =~ s|\.?([.\w\-]+)||) {# classes
+    while ($attrs =~ s|\.?([.\S\-]+)||) {# classes
       #~ warn "\tclass=", $1;
       $parent->{class} .= " $1";
     }
-    while ($attrs =~ s|#([\w\-]+)||) {# id
+    while ($attrs =~ s|#([\S\-]+)||i) {# id
       #~ warn "\tid=", $1;
       $parent->{id}  = $1;
     }
